//
//  ArchiveDict.swift
//  SwiftArchiving
//
//  Created by Marcel Zickler on 13.12.16.
//  Wrapper for NSMutableDictionary to only accept Strings and Ints
//

import Foundation

class ArchiveDict {
    
    var dict: NSMutableDictionary
    
    var debugDescription: String{
        get{
            return dict.debugDescription
        }
    }
    
    var description: String {
        get{
            return dict.description
        }
    }
    
    init() {
        dict = NSMutableDictionary()
    }
    
    init?(contentsOfFile path: String){
        if let d = NSMutableDictionary(contentsOfFile: path){
            dict = d
        }else{
            return nil
        }
        
    }
    
    //casts to NSNumber, because plists don't allow Ints
    public func putInt(_ value: Int, forKey key: String){
        dict.setValue(NSNumber(value: value), forKey: key)
    }
    
    public func putString(_ value: String, forKey key: String){
        dict.setValue(value, forKey: key)
    }
    
    public func write(toFile file: String) -> Bool{
        return dict.write(toFile: file, atomically: true)
    }
    
    public func getInt(forKey key: String) -> Int?{
        return dict.value(forKey: key) as? Int
    }
    
    public func getString(forKey key: String) -> String?{
        return dict.value(forKey: key) as? String
    }
    
}
