//
//  Car.swift
//  SwiftArchiving
//
//  Created by Marcel Zickler on 13.12.16.
//  Subclass of Vehicle with additional instance variables
//
import Foundation

class Car: Vehicle{
    
    let hp: Int
    let maxKph: Int
    let licensePlate: String
    //for showing it on UI
    override var description: String{
        get{
            return "Car: \(model) from \(manufacturer) with \(hp) HP, max tempo of \(maxKph) and \(numberOfWheels) Wheels"
        }
    }
    
    static let KEY_HP = "hp"
    static let KEY_MAX_KPH = "maxKph"
    static let KEY_LICENSE_PLATE = "licensePlate"
    
    init(manufacturer: String, model: String, hp: Int, maxKph: Int, licensePlate: String) {
        self.hp = hp;
        self.maxKph = maxKph;
        self.licensePlate = licensePlate
        super.init(manufacturer: manufacturer, model: model, numberOfWheels: 4)
    }
    
    //have to get all items from the dict and initialize this class with them
    required convenience init(withDict dict: ArchiveDict) {
        if let lp = dict.getString(forKey: Car.KEY_LICENSE_PLATE),
            let kph = dict.getInt(forKey: Car.KEY_MAX_KPH),
            let hp = dict.getInt(forKey: Car.KEY_HP),
            let man = dict.getString(forKey: Car.KEY_MANUFACTURER),
            let mod = dict.getString(forKey: Car.KEY_MODEL){
                self.init(manufacturer: man, model: mod, hp: hp, maxKph: kph, licensePlate: lp)
        }else{
            fatalError("cannot init with dict, because some key is missing")
        }
    }
    
    //encode all variables from parent and then its own
    override func encode(withDict dict: inout ArchiveDict){
        super.encode(withDict: &dict)
        dict.putString(licensePlate, forKey: Car.KEY_LICENSE_PLATE)
        dict.putInt(hp, forKey: Car.KEY_HP)
        dict.putInt(maxKph, forKey: Car.KEY_MAX_KPH)
    }
    
}
