//
//  CreateObjectViewController.swift
//  SwiftArchiving
//
//  Created by Marcel Zickler on 13.12.16.
//  Implementation only for presentation purpose.
//  Does not cover special cases, such as trying to create objects with nil values.
//  Also many rules of good programming were violated while writing this file.
//

import UIKit

class CreateObjectViewController: UIViewController {

    @IBOutlet var selectSC: UISegmentedControl!
    
    @IBOutlet var manufacturerTv: UITextField!
    @IBOutlet var modelTv: UITextField!
    @IBOutlet var numWheelsTv: UITextField!
    @IBOutlet var maxKphTv: UITextField!
    @IBOutlet var hpTv: UITextField!
    @IBOutlet var frameSizeTv: UITextField!
    @IBOutlet var bicycleTypeTv: UITextField!
    @IBOutlet var licensePlateTv: UITextField!
    
    private let onSave: (Any) -> () //little cheat for not using segues
    private static var archiveCounter = 0//for "dynamic" file names. Will override old plists when restarting, because archiveCounter will be 0 again
    
    init(onSave: @escaping (Any) -> ()){
        self.onSave = onSave
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder aDecoder: NSCoder) {
        //not needed for this implementation
        fatalError("not implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }
    
    
    @IBAction func saveOnClick(_ sender: AnyObject) {
        let obj: SwiftCoding
        switch selectSC.selectedSegmentIndex {
            //create a obj object with data from boxes. When requiered boxes are empty an error will occur. Also, it is not checked wheather the user only typed number literals when casting to int
            case 1:
                obj = Car(manufacturer: manufacturerTv.text!, model: modelTv.text!, hp: Int(hpTv.text!)!, maxKph: Int(maxKphTv.text!)!, licensePlate: licensePlateTv.text!)
            case 2:
                obj = Bicycle(manufacturer: manufacturerTv.text!, model: modelTv.text!, type: bicycleTypeTv.text!, frameSize: Int(frameSizeTv.text!)!)
            default:
                obj = Vehicle(manufacturer: manufacturerTv.text!, model: modelTv.text!, numberOfWheels: Int(numWheelsTv.text!)!)
        }
        archive(obj)
        onSave(obj) //adds object to list in MasterViewController
        self.navigationController?.popViewController(animated: true)
    }
    
    //archives the object created in this view controller
    private func archive(_ obj: SwiftCoding){
        //generate path for plist with "unique" id for this object
        let documentDirectory = NSSearchPathForDirectoriesInDomains(.documentDirectory, .userDomainMask, true)[0] as String
        let path = documentDirectory.appending("/serialized_\(CreateObjectViewController.archiveCounter).plist")
        //the actual archiving
        do{
            let success = try SwiftKeyedArchiver.archive(rootObject: obj, toFile: path)
            if(success){
                print("saved at \(path)")
                CreateObjectViewController.archiveCounter += 1
            }
        } catch let error{
            print("could not archive object: \(error.localizedDescription)")
        }
    }
    
    @IBAction func cancelOnClick(_ sender: AnyObject) {
        self.navigationController?.popViewController(animated: true)
    }
    
    //hide views not needed
    @IBAction func switchOnValueChanged(_ sender: AnyObject) {
        switch selectSC.selectedSegmentIndex {
        case 1:
            //car
            hpTv.isHidden = false
            maxKphTv.isHidden = false
            licensePlateTv.isHidden = false
            frameSizeTv.isHidden = true
            bicycleTypeTv.isHidden = true
            numWheelsTv.isHidden = true
        case 2:
            //bicycle
            hpTv.isHidden = true
            maxKphTv.isHidden = true
            licensePlateTv.isHidden = true
            frameSizeTv.isHidden = false
            bicycleTypeTv.isHidden = false
            numWheelsTv.isHidden = true
        default:
            //vehicle
            hpTv.isHidden = true
            maxKphTv.isHidden = true
            licensePlateTv.isHidden = true
            frameSizeTv.isHidden = true
            bicycleTypeTv.isHidden = true
            numWheelsTv.isHidden = false
        }

    }
    
    
 

}
