import Foundation

class Vehicle: SwiftCoding{
    
    let manufacturer: String
    let model: String
    let numberOfWheels: Int
    //for showing it on UI
    var description : String {
        get{
            return "Vehicle: \(model) from \(manufacturer) with \(numberOfWheels) Wheels"
        }
    }
    
    static let KEY_MANUFACTURER = "manufacturer"
    static let KEY_MODEL = "model"
    static let KEY_NUMBER_OF_WHEELS = "numberOfWheels"
    
    init(manufacturer: String, model: String, numberOfWheels: Int) {
        self.manufacturer = manufacturer
        self.model = model
        self.numberOfWheels = numberOfWheels
    }
    
    //implemented because of SwiftCoding
    //have to get all items from the dict and initialize this class with them
    required convenience init(withDict dict: ArchiveDict) {
        if let man = dict.getString(forKey: Vehicle.KEY_MANUFACTURER),
            let mod = dict.getString(forKey: Vehicle.KEY_MODEL),
            let nw = dict.getInt(forKey: Vehicle.KEY_NUMBER_OF_WHEELS){
                self.init(manufacturer: man, model: mod, numberOfWheels: nw)
        }else{
            fatalError("cannot init with dict, because some key is missing")
        }
    }
    
    //implemented because of SwiftCoding
    //encode all variables
    func encode(withDict dict: inout ArchiveDict) {
        dict.putString(manufacturer, forKey: Vehicle.KEY_MANUFACTURER)
        dict.putString(model, forKey: Vehicle.KEY_MODEL)
        dict.putInt(numberOfWheels, forKey: Vehicle.KEY_NUMBER_OF_WHEELS)
    }

}
